==> return_success_or_error-0.4.2.tar.gz: CHANGELOG.md <==
## [0.4.2] - 18/09/2022.

Correção do export Presenter e ajuste na documentação.

## [0.4.1] - 18/09/2022.

Inclusão da interface Presenter, classe abstrata para garantir o retorno de um ReturnSuccessOrError.

## [0.4.0] - 28/08/2022.

Refator ReturnSuccessOrError com implantação do enum StatusResult. Agora o acesso ao retorno é dado pelo ".result", e o acesso ao status é dado pelo ".status", onde retorna o enum "StatusResult.success" ou "StatusResult.error".

## [0.3.1] - 07/10/2021.

Refator interfaces e mudança dos metodos ´´´returnUseCase´´´, ´´´returnDatasource´´´, ´´´returnRepository´´´ para mixin.

## [0.3.0] - 07/10/2021.

Correção de bug. Antes ´´´UseCase<Tipo> extends UseCaseImplement<tipo>´´´; Depois ´´´UseCase extends UseCaseImplement<Tipo>´´´. Documentação Corrigida.

## [0.2.0] - 25/03/2021.

**BREAKING** Acrescentado na Classe "ParametersReturnResult", a necessidade do "showRuntimeMilliseconds" e "nameFeature". Classe "ReturnResulPresenter" substituida pela inteface UseCaseImplement.

## [0.1.8] - 25/03/2021.

Documentation update.

## [0.1.7] - 19/03/2021.

Documentation update.

## [0.1.6] - 14/03/2021.

Documentation update.

## [0.1.5] - 14/03/2021.

**BREAKING** Removido a necessidade de tipar os parametros direto na classe: Antes ´´´UseCase<bool, Parameters>´´´; Depois ´´´UseCase<bool>´´´. Agora todos os ´´´Parameters´´´ precisam ser implementados de ´´´ParametersReturnResult´´´. A classe abstrata ´´´ParametersReturnResult´´´ recebe agora na implementação o ´´´AppError´´´ direto em vez da ´´´String messageError´´´. O método ´´´returnResult´´´ da classe ´´´ReturnResultUsecaseImplement´´´ foi renomeado para ´´´call´´´ e não precisa mais ser informado. 

## [0.1.4] - 14/03/2021.

Correction of readmes and exexample.

## [0.1.3] - 14/03/2021.

Correction of environment flutter >= 2.0.0.

## [0.1.2] - 14/03/2021.

**BREAKING** Correction of the class name ´´´ErroReturnResult´´´ for ´´´ErrorReturnResult´´´.

## [0.1.1] - 14/03/2021.

Correction of readmes and creation of readme-pt.md.

## [0.1.0] - 13/03/2021.

Initial release.

==> return_success_or_error-0.7.0.tar.gz: CHANGELOG.md <==
## [0.7.0] - 28/05/2023.

1 - Refator parar compatibilidade do dart 3.
2 - Restruturação do cógigo onde agorar será retornado um record contendo o resultado e o erro.
3 - Use case agora processa os dados do datasource e retorna os dados separadamente. Onde é definido na estensão a tipagem do usecase e a ttipagem do datasouce separardamente.
4 - Reestruturação da class base ParametersReturnResult. Onde os dados em comum serão agora ParametersBasic.

## [0.5.0] - 18/09/2022.

1 - Inclusão de isIsolate em ParametersReturnResult.
2 - Abilitação do datasource executado em isolate.
3 - Atualizaçã do Exemplo.

## [0.4.2] - 18/09/2022.

Correção do export Presenter e ajuste na documentação.

## [0.4.1] - 18/09/2022.

Inclusão da interface Presenter, classe abstrata para garantir o retorno de um ReturnSuccessOrError.

## [0.4.0] - 28/08/2022.

Refator ReturnSuccessOrError com implantação do enum StatusResult. Agora o acesso ao retorno é dado pelo ".result", e o acesso ao status é dado pelo ".status", onde retorna o enum "StatusResult.success" ou "StatusResult.error".

## [0.3.1] - 07/10/2021.

Refator interfaces e mudança dos metodos ´´´returnUseCase´´´, ´´´returnDatasource´´´, ´´´returnRepository´´´ para mixin.

## [0.3.0] - 07/10/2021.

Correção de bug. Antes ´´´UseCase<Tipo> extends UseCaseImplement<tipo>´´´; Depois ´´´UseCase extends UseCaseImplement<Tipo>´´´. Documentação Corrigida.

## [0.2.0] - 25/03/2021.

**BREAKING** Acrescentado na Classe "ParametersReturnResult", a necessidade do "showRuntimeMilliseconds" e "nameFeature". Classe "ReturnResulPresenter" substituida pela inteface UseCaseImplement.

## [0.1.8] - 25/03/2021.

Documentation update.

## [0.1.7] - 19/03/2021.

Documentation update.

## [0.1.6] - 14/03/2021.

Documentation update.

## [0.1.5] - 14/03/2021.

**BREAKING** Removido a necessidade de tipar os parametros direto na classe: Antes ´´´UseCase<bool, Parameters>´´´; Depois ´´´UseCase<bool>´´´. Agora todos os ´´´Parameters´´´ precisam ser implementados de ´´´ParametersReturnResult´´´. A classe abstrata ´´´ParametersReturnResult´´´ recebe agora na implementação o ´´´AppError´´´ direto em vez da ´´´String messageError´´´. O método ´´´returnResult´´´ da classe ´´´ReturnResultUsecaseImplement´´´ foi renomeado para ´´´call´´´ e não precisa mais ser informado. 

## [0.1.4] - 14/03/2021.

Correction of readmes and exexample.

## [0.1.3] - 14/03/2021.

Correction of environment flutter >= 2.0.0.

## [0.1.2] - 14/03/2021.

**BREAKING** Correction of the class name ´´´ErroReturnResult´´´ for ´´´ErrorGeneric´´´.

## [0.1.1] - 14/03/2021.

Correction of readmes and creation of readme-pt.md.

## [0.1.0] - 13/03/2021.

Initial release.
